@@ -132,6 +132,7 @@ static const ModelIdMap modelid_map = {
     { 386, OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM3A) },
     { 387, OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM4A) },
     { 388, OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7M4) },
+    { 390, OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM5) },
 };
 
 /* taken from dcraw, by default */
@@ -449,6 +450,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 7662, -2686, -660, -5240, 12965, 2530, -796, 1508, 6167 } },
+    { OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM5),
+      0,
+      0,
+      { 8200, -2976, -719, -4296, 12053, 2532, -429, 1282, 5774 } },
     { OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7S),
       128,
       0,
@@ -579,6 +584,7 @@ const IfdFile::camera_ids_t ArwFile::s_def[] = {
     { "ILCE-7RM3A", OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM3A) },
     { "ILCE-7RM4", OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM4) },
     { "ILCE-7RM4A", OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM4A) },
+    { "ILCE-7RM5", OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7RM5) },
     { "ILCE-7S", OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7S) },
     { "ILCE-7SM2", OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7SM2) },
     { "ILCE-7SM3", OR_MAKE_SONY_TYPEID(OR_TYPEID_SONY_ILCE7SM3) },
