@@ -204,6 +204,8 @@ const IfdFile::camera_ids_t DngFile::s_def[] = {
                                         OR_TYPEID_SIGMA_FP_L) },
     { "L1D-20c", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_HASSELBLAD,
                                      OR_TYPEID_HASSELBLAD_L1D_20C) },
+    { "L2D-20c", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_HASSELBLAD,
+                                     OR_TYPEID_HASSELBLAD_L2D_20C) },
     { "HERO5 Black", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_GOPRO,
                                       OR_TYPEID_GOPRO_HERO5_BLACK) },
     { "HERO6 Black", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_GOPRO,
@@ -222,6 +224,8 @@ const IfdFile::camera_ids_t DngFile::s_def[] = {
                                    OR_TYPEID_DJI_FC220) },
     { "FC350", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_DJI,
                                    OR_TYPEID_DJI_FC350) },
+    { "FC3582", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_DJI,
+                                    OR_TYPEID_DJI_FC3582) },
     { "FC6310", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_DJI,
                                     OR_TYPEID_DJI_FC6310) },
     { "FC7303", OR_MAKE_FILE_TYPEID(OR_TYPEID_VENDOR_DJI,
