@@ -1,7 +1,7 @@
 /*
  * libopenraw - rw2file.cpp
  *
- * Copyright (C) 2011-2022 Hubert Figuière
+ * Copyright (C) 2011-2023 Hubert Figuière
  *
  * This library is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -485,6 +485,7 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DC-G90", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G90) },
     { "DC-G91", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G91) },
     { "DC-G95", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G95) },
+    { "DC-G95D", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G95D) },
     { "DC-G99", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G99) },
     { "DC-G100", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G100) },
     { "DC-G110", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_G110) },
@@ -515,6 +516,7 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DC-S1R", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_S1R) },
     { "DC-S1H", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_S1H) },
     { "DC-S5", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_S5) },
+    { "DC-S5M2", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_S5M2) },
     { "DMC-TZ70", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_TZ70) },
     { "DMC-ZS60", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_ZS60) },
     // Aliases to DMC-ZS60
